# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from properly_model_python.search_models.models.base_model_ import Model
from properly_model_python.search_models import util
from properly_model_python.search_models.models.lat_lng import LatLng


class LatLngBounds(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, sw: LatLng=None, ne: LatLng=None):  # noqa: E501
        """LatLngBounds - a model defined in Swagger

        :param sw: The sw of this LatLngBounds.  # noqa: E501
        :type sw: LatLng
        :param ne: The ne of this LatLngBounds.  # noqa: E501
        :type ne: LatLng
        """
        self.swagger_types = {
            'sw': LatLng,
            'ne': LatLng
        }

        self.attribute_map = {
            'sw': 'sw',
            'ne': 'ne'
        }

        self._sw = sw
        self._ne = ne

    @classmethod
    def from_dict(cls, dikt) -> 'LatLngBounds':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The LatLngBounds of this LatLngBounds.  # noqa: E501
        :rtype: LatLngBounds
        """
        return util.deserialize_model(dikt, cls)

    @property
    def sw(self) -> LatLng:
        """Gets the sw of this LatLngBounds.


        :return: The sw of this LatLngBounds.
        :rtype: LatLng
        """
        return self._sw

    @sw.setter
    def sw(self, sw: LatLng):
        """Sets the sw of this LatLngBounds.


        :param sw: The sw of this LatLngBounds.
        :type sw: LatLng
        """

        self._sw = sw

    @property
    def ne(self) -> LatLng:
        """Gets the ne of this LatLngBounds.


        :return: The ne of this LatLngBounds.
        :rtype: LatLng
        """
        return self._ne

    @ne.setter
    def ne(self, ne: LatLng):
        """Sets the ne of this LatLngBounds.


        :param ne: The ne of this LatLngBounds.
        :type ne: LatLng
        """

        self._ne = ne



# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from properly_model_python.models.base_model_ import Model
from properly_model_python.alert_models.models.search import Search
from properly_model_python import util


class UsersSearch(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, id: str=None, search_id: str=None, search_data: Search=None, user_id: str=None, last_run_millis: int=None, last_run_search_result_id: str=None):  # noqa: E501
        """UsersSearch - a model defined in Swagger

        :param id: The id of this UsersSearch.  # noqa: E501
        :type id: str
        :param search_id: The search_id of this UsersSearch.  # noqa: E501
        :type search_id: str
        :param search_data: The search_data of this UsersSearch.  # noqa: E501
        :type search_data: Search
        :param user_id: The user_id of this UsersSearch.  # noqa: E501
        :type user_id: str
        :param last_run_millis: The last_run_millis of this UsersSearch.  # noqa: E501
        :type last_run_millis: int
        :param last_run_search_result_id: The last_run_search_result_id of this UsersSearch.  # noqa: E501
        :type last_run_search_result_id: str
        """
        self.swagger_types = {
            'id': str,
            'search_id': str,
            'search_data': Search,
            'user_id': str,
            'last_run_millis': int,
            'last_run_search_result_id': str
        }

        self.attribute_map = {
            'id': 'id',
            'search_id': 'searchId',
            'search_data': 'searchData',
            'user_id': 'userId',
            'last_run_millis': 'lastRunMillis',
            'last_run_search_result_id': 'lastRunSearchResultId'
        }

        self._id = id
        self._search_id = search_id
        self._search_data = search_data
        self._user_id = user_id
        self._last_run_millis = last_run_millis
        self._last_run_search_result_id = last_run_search_result_id

    @classmethod
    def from_dict(cls, dikt) -> 'UsersSearch':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The UsersSearch of this UsersSearch.  # noqa: E501
        :rtype: UsersSearch
        """
        return util.deserialize_model(dikt, cls)

    @property
    def id(self) -> str:
        """Gets the id of this UsersSearch.


        :return: The id of this UsersSearch.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: str):
        """Sets the id of this UsersSearch.


        :param id: The id of this UsersSearch.
        :type id: str
        """

        self._id = id

    @property
    def search_id(self) -> str:
        """Gets the search_id of this UsersSearch.


        :return: The search_id of this UsersSearch.
        :rtype: str
        """
        return self._search_id

    @search_id.setter
    def search_id(self, search_id: str):
        """Sets the search_id of this UsersSearch.


        :param search_id: The search_id of this UsersSearch.
        :type search_id: str
        """

        self._search_id = search_id

    @property
    def search_data(self) -> Search:
        """Gets the search_data of this UsersSearch.


        :return: The search_data of this UsersSearch.
        :rtype: Search
        """
        return self._search_data

    @search_data.setter
    def search_data(self, search_data: Search):
        """Sets the search_data of this UsersSearch.


        :param search_data: The search_data of this UsersSearch.
        :type search_data: Search
        """

        self._search_data = search_data

    @property
    def user_id(self) -> str:
        """Gets the user_id of this UsersSearch.


        :return: The user_id of this UsersSearch.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id: str):
        """Sets the user_id of this UsersSearch.


        :param user_id: The user_id of this UsersSearch.
        :type user_id: str
        """

        self._user_id = user_id

    @property
    def last_run_millis(self) -> int:
        """Gets the last_run_millis of this UsersSearch.


        :return: The last_run_millis of this UsersSearch.
        :rtype: int
        """
        return self._last_run_millis

    @last_run_millis.setter
    def last_run_millis(self, last_run_millis: int):
        """Sets the last_run_millis of this UsersSearch.


        :param last_run_millis: The last_run_millis of this UsersSearch.
        :type last_run_millis: int
        """

        self._last_run_millis = last_run_millis

    @property
    def last_run_search_result_id(self) -> str:
        """Gets the last_run_search_result_id of this UsersSearch.


        :return: The last_run_search_result_id of this UsersSearch.
        :rtype: str
        """
        return self._last_run_search_result_id

    @last_run_search_result_id.setter
    def last_run_search_result_id(self, last_run_search_result_id: str):
        """Sets the last_run_search_result_id of this UsersSearch.


        :param last_run_search_result_id: The last_run_search_result_id of this UsersSearch.
        :type last_run_search_result_id: str
        """

        self._last_run_search_result_id = last_run_search_result_id



# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from properly_model_python.search_models.models.base_model_ import Model
from properly_model_python.search_models import util
from properly_model_python.search_models.models.lat_lng_bounds import LatLngBounds


class Search(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(
        self,
        id: str = None,
        search_hash: str = None,
        last_run_millis: int = None,
        properly_city_code: str = None,
        cities: List[str] = None,
        neighbourhoods: List[str] = None,
        neighbourhoods_v2: List[object] = None,
        addresses: List[str] = None,
        building_types: List[str] = None,
        min_price: int = None,
        max_price: int = None,
        min_beds: int = None,
        min_baths: int = None,
        min_parking: int = None,
        min_square_foot: int = None,
        max_square_foot: int = None,
        geohash6_areas: List[str] = None,
        bounds: LatLngBounds = None,
    ):  # noqa: E501
        """Search - a model defined in Swagger

        :param id: The id of this Search.  # noqa: E501
        :type id: str
        :param search_hash: The search_hash of this Search.  # noqa: E501
        :type search_hash: str
        :param last_run_millis: The last_run_millis of this Search.  # noqa: E501
        :type last_run_millis: int
        :param properly_city_code: The properly_city_code of this Search.  # noqa: E501
        :type properly_city_code: str
        :param cities: The cities of this Search.  # noqa: E501
        :type cities: List[str]
        :param neighbourhoods: The neighbourhoods of this Search.  # noqa: E501
        :type neighbourhoods: List[str]
        :param neighbourhoods_v2: The neighbourhoods_v2 of this Search.  # noqa: E501
        :type neighbourhoods_v2: List[object]
        :param addresses: The addresses of this Search.  # noqa: E501
        :type addresses: List[str]
        :param building_types: The building_types of this Search.  # noqa: E501
        :type building_types: List[str]
        :param min_price: The min_price of this Search.  # noqa: E501
        :type min_price: int
        :param max_price: The max_price of this Search.  # noqa: E501
        :type max_price: int
        :param min_beds: The min_beds of this Search.  # noqa: E501
        :type min_beds: int
        :param min_baths: The min_baths of this Search.  # noqa: E501
        :type min_baths: int
        :param min_parking: The min_parking of this Search.  # noqa: E501
        :type min_parking: int
        :param min_square_foot: The min_square_foot of this Search.  # noqa: E501
        :type min_square_foot: int
        :param max_square_foot: The max_square_foot of this Search.  # noqa: E501
        :type max_square_foot: int
        :param geohash6_areas: The geohash6_areas of this Search.  # noqa: E501
        :type geohash6_areas: List[str]
        :param bounds: The bounds of this Search.  # noqa: E501
        :type bounds: LatLngBounds
        """
        self.swagger_types = {
            "id": str,
            "search_hash": str,
            "last_run_millis": int,
            "properly_city_code": str,
            "cities": List[str],
            "neighbourhoods": List[str],
            "neighbourhoods_v2": List[object],
            "addresses": List[str],
            "building_types": List[str],
            "min_price": int,
            "max_price": int,
            "min_beds": int,
            "min_baths": int,
            "min_parking": int,
            "min_square_foot": int,
            "max_square_foot": int,
            "geohash6_areas": List[str],
            "bounds": LatLngBounds,
        }

        self.attribute_map = {
            "id": "id",
            "search_hash": "searchHash",
            "last_run_millis": "lastRunMillis",
            "properly_city_code": "properlyCityCode",
            "cities": "cities",
            "neighbourhoods": "neighbourhoods",
            "neighbourhoods_v2": "neighbourhoods_v2",
            "addresses": "addresses",
            "building_types": "buildingTypes",
            "min_price": "minPrice",
            "max_price": "maxPrice",
            "min_beds": "minBeds",
            "min_baths": "minBaths",
            "min_parking": "minParking",
            "min_square_foot": "minSquareFoot",
            "max_square_foot": "maxSquareFoot",
            "geohash6_areas": "geohash6Areas",
            "bounds": "bounds",
        }

        self._id = id
        self._search_hash = search_hash
        self._last_run_millis = last_run_millis
        self._properly_city_code = properly_city_code
        self._cities = cities
        self._neighbourhoods = neighbourhoods
        self._neighbourhoods_v2 = neighbourhoods_v2
        self._addresses = addresses
        self._building_types = building_types
        self._min_price = min_price
        self._max_price = max_price
        self._min_beds = min_beds
        self._min_baths = min_baths
        self._min_parking = min_parking
        self._min_square_foot = min_square_foot
        self._max_square_foot = max_square_foot
        self._geohash6_areas = geohash6_areas
        self._bounds = bounds

    @classmethod
    def from_dict(cls, dikt) -> "Search":
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The Search of this Search.  # noqa: E501
        :rtype: Search
        """
        return util.deserialize_model(dikt, cls)

    @property
    def id(self) -> str:
        """Gets the id of this Search.

        unique id for this search definition  # noqa: E501

        :return: The id of this Search.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: str):
        """Sets the id of this Search.

        unique id for this search definition  # noqa: E501

        :param id: The id of this Search.
        :type id: str
        """

        self._id = id

    @property
    def search_hash(self) -> str:
        """Gets the search_hash of this Search.

        proposed as base64urlsafeof(sha512of(jsonstringof(sorted(searchparms))))  # noqa: E501

        :return: The search_hash of this Search.
        :rtype: str
        """
        return self._search_hash

    @search_hash.setter
    def search_hash(self, search_hash: str):
        """Sets the search_hash of this Search.

        proposed as base64urlsafeof(sha512of(jsonstringof(sorted(searchparms))))  # noqa: E501

        :param search_hash: The search_hash of this Search.
        :type search_hash: str
        """

        self._search_hash = search_hash

    @property
    def last_run_millis(self) -> int:
        """Gets the last_run_millis of this Search.


        :return: The last_run_millis of this Search.
        :rtype: int
        """
        return self._last_run_millis

    @last_run_millis.setter
    def last_run_millis(self, last_run_millis: int):
        """Sets the last_run_millis of this Search.


        :param last_run_millis: The last_run_millis of this Search.
        :type last_run_millis: int
        """

        self._last_run_millis = last_run_millis

    @property
    def properly_city_code(self) -> str:
        """Gets the properly_city_code of this Search.

        scoping qualifier for other strings like neighbourhood.  # noqa: E501

        :return: The properly_city_code of this Search.
        :rtype: str
        """
        return self._properly_city_code

    @properly_city_code.setter
    def properly_city_code(self, properly_city_code: str):
        """Sets the properly_city_code of this Search.

        scoping qualifier for other strings like neighbourhood.  # noqa: E501

        :param properly_city_code: The properly_city_code of this Search.
        :type properly_city_code: str
        """

        self._properly_city_code = properly_city_code

    @property
    def cities(self) -> List[str]:
        """Gets the cities of this Search.

        City strings  # noqa: E501

        :return: The cities of this Search.
        :rtype: List[str]
        """
        return self._cities

    @cities.setter
    def cities(self, cities: List[str]):
        """Sets the cities of this Search.

        City strings  # noqa: E501

        :param cities: The cities of this Search.
        :type cities: List[str]
        """

        self._cities = cities

    @property
    def neighbourhoods(self) -> List[str]:
        """Gets the neighbourhoods of this Search.

        Neighbourhood strings  # noqa: E501

        :return: The neighbourhoods of this Search.
        :rtype: List[str]
        """
        return self._neighbourhoods

    @neighbourhoods.setter
    def neighbourhoods(self, neighbourhoods: List[str]):
        """Sets the neighbourhoods of this Search.

        Neighbourhood strings  # noqa: E501

        :param neighbourhoods: The neighbourhoods of this Search.
        :type neighbourhoods: List[str]
        """

        self._neighbourhoods = neighbourhoods

    @property
    def neighbourhoods_v2(self) -> List[object]:
        """Gets the neighbourhoods_v2 of this Search.

        Neighbourhood_v2 objects  # noqa: E501

        :return: The neighbourhoods_v2 of this Search.
        :rtype: List[object]
        """
        return self._neighbourhoods_v2

    @neighbourhoods_v2.setter
    def neighbourhoods_v2(self, neighbourhoods_v2: List[object]):
        """Sets the neighbourhoods_v2 of this Search.

        Neighbourhood_v2 objects  # noqa: E501

        :param neighbourhoods_v2: The neighbourhoods_v2 of this Search.
        :type neighbourhoods_v2: List[object]
        """

        self._neighbourhoods_v2 = neighbourhoods_v2

    @property
    def addresses(self) -> List[str]:
        """Gets the addresses of this Search.

        Specific addresses  # noqa: E501

        :return: The addresses of this Search.
        :rtype: List[str]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses: List[str]):
        """Sets the addresses of this Search.

        Specific addresses  # noqa: E501

        :param addresses: The addresses of this Search.
        :type addresses: List[str]
        """

        self._addresses = addresses

    @property
    def building_types(self) -> List[str]:
        """Gets the building_types of this Search.

        types of homes  # noqa: E501

        :return: The building_types of this Search.
        :rtype: List[str]
        """
        return self._building_types

    @building_types.setter
    def building_types(self, building_types: List[str]):
        """Sets the building_types of this Search.

        types of homes  # noqa: E501

        :param building_types: The building_types of this Search.
        :type building_types: List[str]
        """

        self._building_types = building_types

    @property
    def min_price(self) -> int:
        """Gets the min_price of this Search.

        minimum price to include  # noqa: E501

        :return: The min_price of this Search.
        :rtype: int
        """
        return self._min_price

    @min_price.setter
    def min_price(self, min_price: int):
        """Sets the min_price of this Search.

        minimum price to include  # noqa: E501

        :param min_price: The min_price of this Search.
        :type min_price: int
        """

        self._min_price = min_price

    @property
    def max_price(self) -> int:
        """Gets the max_price of this Search.

        maximum price to include  # noqa: E501

        :return: The max_price of this Search.
        :rtype: int
        """
        return self._max_price

    @max_price.setter
    def max_price(self, max_price: int):
        """Sets the max_price of this Search.

        maximum price to include  # noqa: E501

        :param max_price: The max_price of this Search.
        :type max_price: int
        """

        self._max_price = max_price

    @property
    def min_beds(self) -> int:
        """Gets the min_beds of this Search.


        :return: The min_beds of this Search.
        :rtype: int
        """
        return self._min_beds

    @min_beds.setter
    def min_beds(self, min_beds: int):
        """Sets the min_beds of this Search.


        :param min_beds: The min_beds of this Search.
        :type min_beds: int
        """

        self._min_beds = min_beds

    @property
    def min_baths(self) -> int:
        """Gets the min_baths of this Search.

        inclusive minimum full baths to include  # noqa: E501

        :return: The min_baths of this Search.
        :rtype: int
        """
        return self._min_baths

    @min_baths.setter
    def min_baths(self, min_baths: int):
        """Sets the min_baths of this Search.

        inclusive minimum full baths to include  # noqa: E501

        :param min_baths: The min_baths of this Search.
        :type min_baths: int
        """

        self._min_baths = min_baths

    @property
    def min_parking(self) -> int:
        """Gets the min_parking of this Search.

        inclusive minimum number of parking spots available  # noqa: E501

        :return: The min_parking of this Search.
        :rtype: int
        """
        return self._min_parking

    @min_parking.setter
    def min_parking(self, min_parking: int):
        """Sets the min_parking of this Search.

        inclusive minimum number of parking spots available  # noqa: E501

        :param min_parking: The min_parking of this Search.
        :type min_parking: int
        """

        self._min_parking = min_parking

    @property
    def min_square_foot(self) -> int:
        """Gets the min_square_foot of this Search.

        inclusive minimum above ground size home  # noqa: E501

        :return: The min_square_foot of this Search.
        :rtype: int
        """
        return self._min_square_foot

    @min_square_foot.setter
    def min_square_foot(self, min_square_foot: int):
        """Sets the min_square_foot of this Search.

        inclusive minimum above ground size home  # noqa: E501

        :param min_square_foot: The min_square_foot of this Search.
        :type min_square_foot: int
        """

        self._min_square_foot = min_square_foot

    @property
    def max_square_foot(self) -> int:
        """Gets the max_square_foot of this Search.

        inclusive maxiumum above ground size of home  # noqa: E501

        :return: The max_square_foot of this Search.
        :rtype: int
        """
        return self._max_square_foot

    @max_square_foot.setter
    def max_square_foot(self, max_square_foot: int):
        """Sets the max_square_foot of this Search.

        inclusive maxiumum above ground size of home  # noqa: E501

        :param max_square_foot: The max_square_foot of this Search.
        :type max_square_foot: int
        """

        self._max_square_foot = max_square_foot

    @property
    def geohash6_areas(self) -> List[str]:
        """Gets the geohash6_areas of this Search.

        list of geohash6 areas to include  # noqa: E501

        :return: The geohash6_areas of this Search.
        :rtype: List[str]
        """
        return self._geohash6_areas

    @geohash6_areas.setter
    def geohash6_areas(self, geohash6_areas: List[str]):
        """Sets the geohash6_areas of this Search.

        list of geohash6 areas to include  # noqa: E501

        :param geohash6_areas: The geohash6_areas of this Search.
        :type geohash6_areas: List[str]
        """

        self._geohash6_areas = geohash6_areas

    @property
    def bounds(self) -> LatLngBounds:
        """Gets the bounds of this Search.


        :return: The bounds of this Search.
        :rtype: LatLngBounds
        """
        return self._bounds

    @bounds.setter
    def bounds(self, bounds: LatLngBounds):
        """Sets the bounds of this Search.


        :param bounds: The bounds of this Search.
        :type bounds: LatLngBounds
        """

        self._bounds = bounds



# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from properly_model_python.models.base_model_ import Model
from properly_model_python import util


class Image(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, id: str=None, url: str=None, title: str=None, description: str=None, thumbnail_url: str=None, thumbnail_hash: str=None, medium_url: str=None, medium_hash: str=None, large_url: str=None, large_hash: str=None):  # noqa: E501
        """Image - a model defined in Swagger

        :param id: The id of this Image.  # noqa: E501
        :type id: str
        :param url: The url of this Image.  # noqa: E501
        :type url: str
        :param title: The title of this Image.  # noqa: E501
        :type title: str
        :param description: The description of this Image.  # noqa: E501
        :type description: str
        :param thumbnail_url: The thumbnail_url of this Image.  # noqa: E501
        :type thumbnail_url: str
        :param thumbnail_hash: The thumbnail_hash of this Image.  # noqa: E501
        :type thumbnail_hash: str
        :param medium_url: The medium_url of this Image.  # noqa: E501
        :type medium_url: str
        :param medium_hash: The medium_hash of this Image.  # noqa: E501
        :type medium_hash: str
        :param large_url: The large_url of this Image.  # noqa: E501
        :type large_url: str
        :param large_hash: The large_hash of this Image.  # noqa: E501
        :type large_hash: str
        """
        self.swagger_types = {
            'id': str,
            'url': str,
            'title': str,
            'description': str,
            'thumbnail_url': str,
            'thumbnail_hash': str,
            'medium_url': str,
            'medium_hash': str,
            'large_url': str,
            'large_hash': str
        }

        self.attribute_map = {
            'id': 'id',
            'url': 'url',
            'title': 'title',
            'description': 'description',
            'thumbnail_url': 'thumbnail_url',
            'thumbnail_hash': 'thumbnail_hash',
            'medium_url': 'medium_url',
            'medium_hash': 'medium_hash',
            'large_url': 'large_url',
            'large_hash': 'large_hash'
        }

        self._id = id
        self._url = url
        self._title = title
        self._description = description
        self._thumbnail_url = thumbnail_url
        self._thumbnail_hash = thumbnail_hash
        self._medium_url = medium_url
        self._medium_hash = medium_hash
        self._large_url = large_url
        self._large_hash = large_hash

    @classmethod
    def from_dict(cls, dikt) -> 'Image':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The Image of this Image.  # noqa: E501
        :rtype: Image
        """
        return util.deserialize_model(dikt, cls)

    @property
    def id(self) -> str:
        """Gets the id of this Image.


        :return: The id of this Image.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: str):
        """Sets the id of this Image.


        :param id: The id of this Image.
        :type id: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def url(self) -> str:
        """Gets the url of this Image.


        :return: The url of this Image.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url: str):
        """Sets the url of this Image.


        :param url: The url of this Image.
        :type url: str
        """

        self._url = url

    @property
    def title(self) -> str:
        """Gets the title of this Image.


        :return: The title of this Image.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title: str):
        """Sets the title of this Image.


        :param title: The title of this Image.
        :type title: str
        """

        self._title = title

    @property
    def description(self) -> str:
        """Gets the description of this Image.


        :return: The description of this Image.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description: str):
        """Sets the description of this Image.


        :param description: The description of this Image.
        :type description: str
        """

        self._description = description

    @property
    def thumbnail_url(self) -> str:
        """Gets the thumbnail_url of this Image.


        :return: The thumbnail_url of this Image.
        :rtype: str
        """
        return self._thumbnail_url

    @thumbnail_url.setter
    def thumbnail_url(self, thumbnail_url: str):
        """Sets the thumbnail_url of this Image.


        :param thumbnail_url: The thumbnail_url of this Image.
        :type thumbnail_url: str
        """

        self._thumbnail_url = thumbnail_url

    @property
    def thumbnail_hash(self) -> str:
        """Gets the thumbnail_hash of this Image.


        :return: The thumbnail_hash of this Image.
        :rtype: str
        """
        return self._thumbnail_hash

    @thumbnail_hash.setter
    def thumbnail_hash(self, thumbnail_hash: str):
        """Sets the thumbnail_hash of this Image.


        :param thumbnail_hash: The thumbnail_hash of this Image.
        :type thumbnail_hash: str
        """

        self._thumbnail_hash = thumbnail_hash

    @property
    def medium_url(self) -> str:
        """Gets the medium_url of this Image.


        :return: The medium_url of this Image.
        :rtype: str
        """
        return self._medium_url

    @medium_url.setter
    def medium_url(self, medium_url: str):
        """Sets the medium_url of this Image.


        :param medium_url: The medium_url of this Image.
        :type medium_url: str
        """

        self._medium_url = medium_url

    @property
    def medium_hash(self) -> str:
        """Gets the medium_hash of this Image.


        :return: The medium_hash of this Image.
        :rtype: str
        """
        return self._medium_hash

    @medium_hash.setter
    def medium_hash(self, medium_hash: str):
        """Sets the medium_hash of this Image.


        :param medium_hash: The medium_hash of this Image.
        :type medium_hash: str
        """

        self._medium_hash = medium_hash

    @property
    def large_url(self) -> str:
        """Gets the large_url of this Image.


        :return: The large_url of this Image.
        :rtype: str
        """
        return self._large_url

    @large_url.setter
    def large_url(self, large_url: str):
        """Sets the large_url of this Image.


        :param large_url: The large_url of this Image.
        :type large_url: str
        """

        self._large_url = large_url

    @property
    def large_hash(self) -> str:
        """Gets the large_hash of this Image.


        :return: The large_hash of this Image.
        :rtype: str
        """
        return self._large_hash

    @large_hash.setter
    def large_hash(self, large_hash: str):
        """Sets the large_hash of this Image.


        :param large_hash: The large_hash of this Image.
        :type large_hash: str
        """

        self._large_hash = large_hash



# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from properly_model_python.models.base_model_ import Model
from properly_model_python import util


class UsersRecommendation(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, id: str=None, user_id: str=None, enabled: int=None, properly_city_code: str=None, created_at_millis: int=None, updated_at_millis: int=None):  # noqa: E501
        """UsersRecommendation - a model defined in Swagger

        :param id: The id of this UsersRecommendation.  # noqa: E501
        :type id: str
        :param user_id: The user_id of this UsersRecommendation.  # noqa: E501
        :type user_id: str
        :param enabled: The enabled of this UsersRecommendation.  # noqa: E501
        :type enabled: int
        :param properly_city_code: The properly_city_code of this UsersRecommendation.  # noqa: E501
        :type properly_city_code: str
        :param created_at_millis: The created_at_millis of this UsersRecommendation.  # noqa: E501
        :type created_at_millis: int
        :param updated_at_millis: The updated_at_millis of this UsersRecommendation.  # noqa: E501
        :type updated_at_millis: int
        """
        self.swagger_types = {
            'id': str,
            'user_id': str,
            'enabled': int,
            'properly_city_code': str,
            'created_at_millis': int,
            'updated_at_millis': int
        }

        self.attribute_map = {
            'id': 'id',
            'user_id': 'userId',
            'enabled': 'enabled',
            'properly_city_code': 'properlyCityCode',
            'created_at_millis': 'createdAtMillis',
            'updated_at_millis': 'updatedAtMillis'
        }

        self._id = id
        self._user_id = user_id
        self._enabled = enabled
        self._properly_city_code = properly_city_code
        self._created_at_millis = created_at_millis
        self._updated_at_millis = updated_at_millis

    @classmethod
    def from_dict(cls, dikt) -> 'UsersRecommendation':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The UsersRecommendation of this UsersRecommendation.  # noqa: E501
        :rtype: UsersRecommendation
        """
        return util.deserialize_model(dikt, cls)

    @property
    def id(self) -> str:
        """Gets the id of this UsersRecommendation.


        :return: The id of this UsersRecommendation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: str):
        """Sets the id of this UsersRecommendation.


        :param id: The id of this UsersRecommendation.
        :type id: str
        """

        self._id = id

    @property
    def user_id(self) -> str:
        """Gets the user_id of this UsersRecommendation.


        :return: The user_id of this UsersRecommendation.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id: str):
        """Sets the user_id of this UsersRecommendation.


        :param user_id: The user_id of this UsersRecommendation.
        :type user_id: str
        """

        self._user_id = user_id

    @property
    def enabled(self) -> int:
        """Gets the enabled of this UsersRecommendation.


        :return: The enabled of this UsersRecommendation.
        :rtype: int
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled: int):
        """Sets the enabled of this UsersRecommendation.


        :param enabled: The enabled of this UsersRecommendation.
        :type enabled: int
        """

        self._enabled = enabled

    @property
    def properly_city_code(self) -> str:
        """Gets the properly_city_code of this UsersRecommendation.

        properly city code  # noqa: E501

        :return: The properly_city_code of this UsersRecommendation.
        :rtype: str
        """
        return self._properly_city_code

    @properly_city_code.setter
    def properly_city_code(self, properly_city_code: str):
        """Sets the properly_city_code of this UsersRecommendation.

        properly city code  # noqa: E501

        :param properly_city_code: The properly_city_code of this UsersRecommendation.
        :type properly_city_code: str
        """

        self._properly_city_code = properly_city_code

    @property
    def created_at_millis(self) -> int:
        """Gets the created_at_millis of this UsersRecommendation.


        :return: The created_at_millis of this UsersRecommendation.
        :rtype: int
        """
        return self._created_at_millis

    @created_at_millis.setter
    def created_at_millis(self, created_at_millis: int):
        """Sets the created_at_millis of this UsersRecommendation.


        :param created_at_millis: The created_at_millis of this UsersRecommendation.
        :type created_at_millis: int
        """

        self._created_at_millis = created_at_millis

    @property
    def updated_at_millis(self) -> int:
        """Gets the updated_at_millis of this UsersRecommendation.


        :return: The updated_at_millis of this UsersRecommendation.
        :rtype: int
        """
        return self._updated_at_millis

    @updated_at_millis.setter
    def updated_at_millis(self, updated_at_millis: int):
        """Sets the updated_at_millis of this UsersRecommendation.


        :param updated_at_millis: The updated_at_millis of this UsersRecommendation.
        :type updated_at_millis: int
        """

        self._updated_at_millis = updated_at_millis



# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from properly_model_python.models.base_model_ import Model
from properly_model_python import util


class CustomAnnotation(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, id: str=None, value: object=None, annotation_group: str=None):  # noqa: E501
        """CustomAnnotation - a model defined in Swagger

        :param id: The id of this CustomAnnotation.  # noqa: E501
        :type id: str
        :param value: The value of this CustomAnnotation.  # noqa: E501
        :type value: object
        :param annotation_group: The annotation_group of this CustomAnnotation.  # noqa: E501
        :type annotation_group: str
        """
        self.swagger_types = {
            'id': str,
            'value': object,
            'annotation_group': str
        }

        self.attribute_map = {
            'id': 'id',
            'value': 'value',
            'annotation_group': 'annotationGroup'
        }

        self._id = id
        self._value = value
        self._annotation_group = annotation_group

    @classmethod
    def from_dict(cls, dikt) -> 'CustomAnnotation':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The CustomAnnotation of this CustomAnnotation.  # noqa: E501
        :rtype: CustomAnnotation
        """
        return util.deserialize_model(dikt, cls)

    @property
    def id(self) -> str:
        """Gets the id of this CustomAnnotation.


        :return: The id of this CustomAnnotation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: str):
        """Sets the id of this CustomAnnotation.


        :param id: The id of this CustomAnnotation.
        :type id: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def value(self) -> object:
        """Gets the value of this CustomAnnotation.


        :return: The value of this CustomAnnotation.
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value: object):
        """Sets the value of this CustomAnnotation.


        :param value: The value of this CustomAnnotation.
        :type value: object
        """
        if value is None:
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def annotation_group(self) -> str:
        """Gets the annotation_group of this CustomAnnotation.


        :return: The annotation_group of this CustomAnnotation.
        :rtype: str
        """
        return self._annotation_group

    @annotation_group.setter
    def annotation_group(self, annotation_group: str):
        """Sets the annotation_group of this CustomAnnotation.


        :param annotation_group: The annotation_group of this CustomAnnotation.
        :type annotation_group: str
        """
        if annotation_group is None:
            raise ValueError("Invalid value for `annotation_group`, must not be `None`")  # noqa: E501

        self._annotation_group = annotation_group



# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from properly_model_python.models.base_model_ import Model
from properly_model_python.alert_models.models.person import Person
from properly_model_python.alert_models.models.simple_listing import SimpleListing
from properly_model_python import util


class AlertNotification(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, id: str=None, alert_type: str=None, user: Person=None, new_results: List[SimpleListing]=None, unsubscribe_url: str=None):  # noqa: E501
        """AlertNotification - a model defined in Swagger

        :param id: The id of this AlertNotification.  # noqa: E501
        :type id: str
        :param alert_type: The alert_type of this AlertNotification.  # noqa: E501
        :type alert_type: str
        :param user: The user of this AlertNotification.  # noqa: E501
        :type user: Person
        :param new_results: The new_results of this AlertNotification.  # noqa: E501
        :type new_results: List[SimpleListing]
        :param unsubscribe_url: The unsubscribe_url of this AlertNotification.  # noqa: E501
        :type unsubscribe_url: str
        """
        self.swagger_types = {
            'id': str,
            'alert_type': str,
            'user': Person,
            'new_results': List[SimpleListing],
            'unsubscribe_url': str
        }

        self.attribute_map = {
            'id': 'id',
            'alert_type': 'alertType',
            'user': 'user',
            'new_results': 'newResults',
            'unsubscribe_url': 'unsubscribeUrl'
        }

        self._id = id
        self._alert_type = alert_type
        self._user = user
        self._new_results = new_results
        self._unsubscribe_url = unsubscribe_url

    @classmethod
    def from_dict(cls, dikt) -> 'AlertNotification':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The AlertNotification of this AlertNotification.  # noqa: E501
        :rtype: AlertNotification
        """
        return util.deserialize_model(dikt, cls)

    @property
    def id(self) -> str:
        """Gets the id of this AlertNotification.

        identifies the notification  # noqa: E501

        :return: The id of this AlertNotification.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: str):
        """Sets the id of this AlertNotification.

        identifies the notification  # noqa: E501

        :param id: The id of this AlertNotification.
        :type id: str
        """

        self._id = id

    @property
    def alert_type(self) -> str:
        """Gets the alert_type of this AlertNotification.

        The type of alert notification this is  # noqa: E501

        :return: The alert_type of this AlertNotification.
        :rtype: str
        """
        return self._alert_type

    @alert_type.setter
    def alert_type(self, alert_type: str):
        """Sets the alert_type of this AlertNotification.

        The type of alert notification this is  # noqa: E501

        :param alert_type: The alert_type of this AlertNotification.
        :type alert_type: str
        """

        self._alert_type = alert_type

    @property
    def user(self) -> Person:
        """Gets the user of this AlertNotification.


        :return: The user of this AlertNotification.
        :rtype: Person
        """
        return self._user

    @user.setter
    def user(self, user: Person):
        """Sets the user of this AlertNotification.


        :param user: The user of this AlertNotification.
        :type user: Person
        """

        self._user = user

    @property
    def new_results(self) -> List[SimpleListing]:
        """Gets the new_results of this AlertNotification.


        :return: The new_results of this AlertNotification.
        :rtype: List[SimpleListing]
        """
        return self._new_results

    @new_results.setter
    def new_results(self, new_results: List[SimpleListing]):
        """Sets the new_results of this AlertNotification.


        :param new_results: The new_results of this AlertNotification.
        :type new_results: List[SimpleListing]
        """

        self._new_results = new_results

    @property
    def unsubscribe_url(self) -> str:
        """Gets the unsubscribe_url of this AlertNotification.

        A url which will unsubscribe the authenicated user from the alert.  # noqa: E501

        :return: The unsubscribe_url of this AlertNotification.
        :rtype: str
        """
        return self._unsubscribe_url

    @unsubscribe_url.setter
    def unsubscribe_url(self, unsubscribe_url: str):
        """Sets the unsubscribe_url of this AlertNotification.

        A url which will unsubscribe the authenicated user from the alert.  # noqa: E501

        :param unsubscribe_url: The unsubscribe_url of this AlertNotification.
        :type unsubscribe_url: str
        """

        self._unsubscribe_url = unsubscribe_url



# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from properly_model_python.models.base_model_ import Model
from properly_model_python import util


class SimpleListing(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, id: str=None, list_price: int=None, predicted_price: float=None, image_url: str=None, image_medium_url: str=None, image_thumbnail_url: str=None, address: str=None, bedrooms: int=None, bathrooms: int=None, bathrooms_half: int=None, square_feet: int=None, parking: int=None, brokerage: str=None, community: str=None, city: str=None, start_date: float=None, mls_id: str=None, listing_brokerage: List[str]=None, property_sub_type: str=None):  # noqa: E501
        """SimpleListing - a model defined in Swagger

        :param id: The id of this SimpleListing.  # noqa: E501
        :type id: str
        :param list_price: The list_price of this SimpleListing.  # noqa: E501
        :type list_price: int
        :param predicted_price: The predicted_price of this SimpleListing.  # noqa: E501
        :type predicted_price: float
        :param image_url: The image_url of this SimpleListing.  # noqa: E501
        :type image_url: str
        :param image_medium_url: The image_medium_url of this SimpleListing.  # noqa: E501
        :type image_medium_url: str
        :param image_thumbnail_url: The image_thumbnail_url of this SimpleListing.  # noqa: E501
        :type image_thumbnail_url: str
        :param address: The address of this SimpleListing.  # noqa: E501
        :type address: str
        :param bedrooms: The bedrooms of this SimpleListing.  # noqa: E501
        :type bedrooms: int
        :param bathrooms: The bathrooms of this SimpleListing.  # noqa: E501
        :type bathrooms: int
        :param bathrooms_half: The bathrooms_half of this SimpleListing.  # noqa: E501
        :type bathrooms_half: int
        :param square_feet: The square_feet of this SimpleListing.  # noqa: E501
        :type square_feet: int
        :param parking: The parking of this SimpleListing.  # noqa: E501
        :type parking: int
        :param brokerage: The brokerage of this SimpleListing.  # noqa: E501
        :type brokerage: str
        :param community: The community of this SimpleListing.  # noqa: E501
        :type community: str
        :param city: The city of this SimpleListing.  # noqa: E501
        :type city: str
        :param start_date: The start_date of this SimpleListing.  # noqa: E501
        :type start_date: float
        :param mls_id: The mls_id of this SimpleListing.  # noqa: E501
        :type mls_id: str
        :param listing_brokerage: The listing_brokerage of this SimpleListing.  # noqa: E501
        :type listing_brokerage: List[str]
        :param property_sub_type: The property_sub_type of this SimpleListing.  # noqa: E501
        :type property_sub_type: str
        """
        self.swagger_types = {
            'id': str,
            'list_price': int,
            'predicted_price': float,
            'image_url': str,
            'image_medium_url': str,
            'image_thumbnail_url': str,
            'address': str,
            'bedrooms': int,
            'bathrooms': int,
            'bathrooms_half': int,
            'square_feet': int,
            'parking': int,
            'brokerage': str,
            'community': str,
            'city': str,
            'start_date': float,
            'mls_id': str,
            'listing_brokerage': List[str],
            'property_sub_type': str
        }

        self.attribute_map = {
            'id': 'id',
            'list_price': 'listPrice',
            'predicted_price': 'predictedPrice',
            'image_url': 'imageUrl',
            'image_medium_url': 'imageMediumUrl',
            'image_thumbnail_url': 'imageThumbnailUrl',
            'address': 'address',
            'bedrooms': 'bedrooms',
            'bathrooms': 'bathrooms',
            'bathrooms_half': 'bathroomsHalf',
            'square_feet': 'squareFeet',
            'parking': 'parking',
            'brokerage': 'brokerage',
            'community': 'community',
            'city': 'city',
            'start_date': 'startDate',
            'mls_id': 'mlsId',
            'listing_brokerage': 'listingBrokerage',
            'property_sub_type': 'propertySubType'
        }

        self._id = id
        self._list_price = list_price
        self._predicted_price = predicted_price
        self._image_url = image_url
        self._image_medium_url = image_medium_url
        self._image_thumbnail_url = image_thumbnail_url
        self._address = address
        self._bedrooms = bedrooms
        self._bathrooms = bathrooms
        self._bathrooms_half = bathrooms_half
        self._square_feet = square_feet
        self._parking = parking
        self._brokerage = brokerage
        self._community = community
        self._city = city
        self._start_date = start_date
        self._mls_id = mls_id
        self._listing_brokerage = listing_brokerage
        self._property_sub_type = property_sub_type

    @classmethod
    def from_dict(cls, dikt) -> 'SimpleListing':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The SimpleListing of this SimpleListing.  # noqa: E501
        :rtype: SimpleListing
        """
        return util.deserialize_model(dikt, cls)

    @property
    def id(self) -> str:
        """Gets the id of this SimpleListing.

        property identifier for this home  # noqa: E501

        :return: The id of this SimpleListing.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: str):
        """Sets the id of this SimpleListing.

        property identifier for this home  # noqa: E501

        :param id: The id of this SimpleListing.
        :type id: str
        """

        self._id = id

    @property
    def list_price(self) -> int:
        """Gets the list_price of this SimpleListing.

        listing price  # noqa: E501

        :return: The list_price of this SimpleListing.
        :rtype: int
        """
        return self._list_price

    @list_price.setter
    def list_price(self, list_price: int):
        """Sets the list_price of this SimpleListing.

        listing price  # noqa: E501

        :param list_price: The list_price of this SimpleListing.
        :type list_price: int
        """

        self._list_price = list_price

    @property
    def predicted_price(self) -> float:
        """Gets the predicted_price of this SimpleListing.

        estimated selling price  # noqa: E501

        :return: The predicted_price of this SimpleListing.
        :rtype: float
        """
        return self._predicted_price

    @predicted_price.setter
    def predicted_price(self, predicted_price: float):
        """Sets the predicted_price of this SimpleListing.

        estimated selling price  # noqa: E501

        :param predicted_price: The predicted_price of this SimpleListing.
        :type predicted_price: float
        """

        self._predicted_price = predicted_price

    @property
    def image_url(self) -> str:
        """Gets the image_url of this SimpleListing.

        Large size of the first image in image list for this property, made available for preview  # noqa: E501

        :return: The image_url of this SimpleListing.
        :rtype: str
        """
        return self._image_url

    @image_url.setter
    def image_url(self, image_url: str):
        """Sets the image_url of this SimpleListing.

        Large size of the first image in image list for this property, made available for preview  # noqa: E501

        :param image_url: The image_url of this SimpleListing.
        :type image_url: str
        """

        self._image_url = image_url

    @property
    def image_medium_url(self) -> str:
        """Gets the image_medium_url of this SimpleListing.

        Medium size of the first image in image list for this property, made available for preview  # noqa: E501

        :return: The image_medium_url of this SimpleListing.
        :rtype: str
        """
        return self._image_medium_url

    @image_medium_url.setter
    def image_medium_url(self, image_medium_url: str):
        """Sets the image_medium_url of this SimpleListing.

        Medium size of the first image in image list for this property, made available for preview  # noqa: E501

        :param image_medium_url: The image_medium_url of this SimpleListing.
        :type image_medium_url: str
        """

        self._image_medium_url = image_medium_url

    @property
    def image_thumbnail_url(self) -> str:
        """Gets the image_thumbnail_url of this SimpleListing.

        Thumbnail size of the first image in image list for this property, made available for preview  # noqa: E501

        :return: The image_thumbnail_url of this SimpleListing.
        :rtype: str
        """
        return self._image_thumbnail_url

    @image_thumbnail_url.setter
    def image_thumbnail_url(self, image_thumbnail_url: str):
        """Sets the image_thumbnail_url of this SimpleListing.

        Thumbnail size of the first image in image list for this property, made available for preview  # noqa: E501

        :param image_thumbnail_url: The image_thumbnail_url of this SimpleListing.
        :type image_thumbnail_url: str
        """

        self._image_thumbnail_url = image_thumbnail_url

    @property
    def address(self) -> str:
        """Gets the address of this SimpleListing.

        Specific addresses  # noqa: E501

        :return: The address of this SimpleListing.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address: str):
        """Sets the address of this SimpleListing.

        Specific addresses  # noqa: E501

        :param address: The address of this SimpleListing.
        :type address: str
        """

        self._address = address

    @property
    def bedrooms(self) -> int:
        """Gets the bedrooms of this SimpleListing.

        Number of bedrooms  # noqa: E501

        :return: The bedrooms of this SimpleListing.
        :rtype: int
        """
        return self._bedrooms

    @bedrooms.setter
    def bedrooms(self, bedrooms: int):
        """Sets the bedrooms of this SimpleListing.

        Number of bedrooms  # noqa: E501

        :param bedrooms: The bedrooms of this SimpleListing.
        :type bedrooms: int
        """

        self._bedrooms = bedrooms

    @property
    def bathrooms(self) -> int:
        """Gets the bathrooms of this SimpleListing.

        Number of full bathrooms  # noqa: E501

        :return: The bathrooms of this SimpleListing.
        :rtype: int
        """
        return self._bathrooms

    @bathrooms.setter
    def bathrooms(self, bathrooms: int):
        """Sets the bathrooms of this SimpleListing.

        Number of full bathrooms  # noqa: E501

        :param bathrooms: The bathrooms of this SimpleListing.
        :type bathrooms: int
        """

        self._bathrooms = bathrooms

    @property
    def bathrooms_half(self) -> int:
        """Gets the bathrooms_half of this SimpleListing.

        Number of half bathrooms  # noqa: E501

        :return: The bathrooms_half of this SimpleListing.
        :rtype: int
        """
        return self._bathrooms_half

    @bathrooms_half.setter
    def bathrooms_half(self, bathrooms_half: int):
        """Sets the bathrooms_half of this SimpleListing.

        Number of half bathrooms  # noqa: E501

        :param bathrooms_half: The bathrooms_half of this SimpleListing.
        :type bathrooms_half: int
        """

        self._bathrooms_half = bathrooms_half

    @property
    def square_feet(self) -> int:
        """Gets the square_feet of this SimpleListing.

        Size of the listing in square feet  # noqa: E501

        :return: The square_feet of this SimpleListing.
        :rtype: int
        """
        return self._square_feet

    @square_feet.setter
    def square_feet(self, square_feet: int):
        """Sets the square_feet of this SimpleListing.

        Size of the listing in square feet  # noqa: E501

        :param square_feet: The square_feet of this SimpleListing.
        :type square_feet: int
        """

        self._square_feet = square_feet

    @property
    def parking(self) -> int:
        """Gets the parking of this SimpleListing.

        Number of parking spaces  # noqa: E501

        :return: The parking of this SimpleListing.
        :rtype: int
        """
        return self._parking

    @parking.setter
    def parking(self, parking: int):
        """Sets the parking of this SimpleListing.

        Number of parking spaces  # noqa: E501

        :param parking: The parking of this SimpleListing.
        :type parking: int
        """

        self._parking = parking

    @property
    def brokerage(self) -> str:
        """Gets the brokerage of this SimpleListing.

        The name of the brokerage listing the property  # noqa: E501

        :return: The brokerage of this SimpleListing.
        :rtype: str
        """
        return self._brokerage

    @brokerage.setter
    def brokerage(self, brokerage: str):
        """Sets the brokerage of this SimpleListing.

        The name of the brokerage listing the property  # noqa: E501

        :param brokerage: The brokerage of this SimpleListing.
        :type brokerage: str
        """

        self._brokerage = brokerage

    @property
    def community(self) -> str:
        """Gets the community of this SimpleListing.

        The community of the listing  # noqa: E501

        :return: The community of this SimpleListing.
        :rtype: str
        """
        return self._community

    @community.setter
    def community(self, community: str):
        """Sets the community of this SimpleListing.

        The community of the listing  # noqa: E501

        :param community: The community of this SimpleListing.
        :type community: str
        """

        self._community = community

    @property
    def city(self) -> str:
        """Gets the city of this SimpleListing.

        The city of the listing (this could be a city, town, etc)  # noqa: E501

        :return: The city of this SimpleListing.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city: str):
        """Sets the city of this SimpleListing.

        The city of the listing (this could be a city, town, etc)  # noqa: E501

        :param city: The city of this SimpleListing.
        :type city: str
        """

        self._city = city

    @property
    def start_date(self) -> float:
        """Gets the start_date of this SimpleListing.

        The start date of the listing  # noqa: E501

        :return: The start_date of this SimpleListing.
        :rtype: float
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date: float):
        """Sets the start_date of this SimpleListing.

        The start date of the listing  # noqa: E501

        :param start_date: The start_date of this SimpleListing.
        :type start_date: float
        """

        self._start_date = start_date

    @property
    def mls_id(self) -> str:
        """Gets the mls_id of this SimpleListing.

        Unique identifier for the MLS listing  # noqa: E501

        :return: The mls_id of this SimpleListing.
        :rtype: str
        """
        return self._mls_id

    @mls_id.setter
    def mls_id(self, mls_id: str):
        """Sets the mls_id of this SimpleListing.

        Unique identifier for the MLS listing  # noqa: E501

        :param mls_id: The mls_id of this SimpleListing.
        :type mls_id: str
        """

        self._mls_id = mls_id

    @property
    def listing_brokerage(self) -> List[str]:
        """Gets the listing_brokerage of this SimpleListing.

        List of brokerages associated with a listing  # noqa: E501

        :return: The listing_brokerage of this SimpleListing.
        :rtype: List[str]
        """
        return self._listing_brokerage

    @listing_brokerage.setter
    def listing_brokerage(self, listing_brokerage: List[str]):
        """Sets the listing_brokerage of this SimpleListing.

        List of brokerages associated with a listing  # noqa: E501

        :param listing_brokerage: The listing_brokerage of this SimpleListing.
        :type listing_brokerage: List[str]
        """

        self._listing_brokerage = listing_brokerage

    @property
    def property_sub_type(self) -> str:
        """Gets the property_sub_type of this SimpleListing.

        Home type of the listing  # noqa: E501

        :return: The property_sub_type of this SimpleListing.
        :rtype: str
        """
        return self._property_sub_type

    @property_sub_type.setter
    def property_sub_type(self, property_sub_type: str):
        """Sets the property_sub_type of this SimpleListing.

        Home type of the listing  # noqa: E501

        :param property_sub_type: The property_sub_type of this SimpleListing.
        :type property_sub_type: str
        """

        self._property_sub_type = property_sub_type




# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from properly_model_python.models.base_model_ import Model
from properly_model_python import util


class UsersAlert(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, alert_type: str=None, user_id: str=None, subscribed: bool=None, unsubscribed: bool=None):  # noqa: E501
        """UsersAlert - a model defined in Swagger

        :param alert_type: The alert_type of this UsersAlert.  # noqa: E501
        :type alert_type: str
        :param user_id: The user_id of this UsersAlert.  # noqa: E501
        :type user_id: str
        :param subscribed: The subscribed of this UsersAlert.  # noqa: E501
        :type subscribed: bool
        :param unsubscribed: The unsubscribed of this UsersAlert.  # noqa: E501
        :type unsubscribed: bool
        """
        self.swagger_types = {
            'alert_type': str,
            'user_id': str,
            'subscribed': bool,
            'unsubscribed': bool
        }

        self.attribute_map = {
            'alert_type': 'alertType',
            'user_id': 'userId',
            'subscribed': 'subscribed',
            'unsubscribed': 'unsubscribed'
        }

        self._alert_type = alert_type
        self._user_id = user_id
        self._subscribed = subscribed
        self._unsubscribed = unsubscribed

    @classmethod
    def from_dict(cls, dikt) -> 'UsersAlert':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The UsersAlert of this UsersAlert.  # noqa: E501
        :rtype: UsersAlert
        """
        return util.deserialize_model(dikt, cls)

    @property
    def alert_type(self) -> str:
        """Gets the alert_type of this UsersAlert.

        Type of alert  # noqa: E501

        :return: The alert_type of this UsersAlert.
        :rtype: str
        """
        return self._alert_type

    @alert_type.setter
    def alert_type(self, alert_type: str):
        """Sets the alert_type of this UsersAlert.

        Type of alert  # noqa: E501

        :param alert_type: The alert_type of this UsersAlert.
        :type alert_type: str
        """

        self._alert_type = alert_type

    @property
    def user_id(self) -> str:
        """Gets the user_id of this UsersAlert.


        :return: The user_id of this UsersAlert.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id: str):
        """Sets the user_id of this UsersAlert.


        :param user_id: The user_id of this UsersAlert.
        :type user_id: str
        """

        self._user_id = user_id

    @property
    def subscribed(self) -> bool:
        """Gets the subscribed of this UsersAlert.

        Whether the alert is currently subscribed to  # noqa: E501

        :return: The subscribed of this UsersAlert.
        :rtype: bool
        """
        return self._subscribed

    @subscribed.setter
    def subscribed(self, subscribed: bool):
        """Sets the subscribed of this UsersAlert.

        Whether the alert is currently subscribed to  # noqa: E501

        :param subscribed: The subscribed of this UsersAlert.
        :type subscribed: bool
        """

        self._subscribed = subscribed

    @property
    def unsubscribed(self) -> bool:
        """Gets the unsubscribed of this UsersAlert.

        Whether the alert has been unsubscribed from. Different from if the alert does not exist yet.  # noqa: E501

        :return: The unsubscribed of this UsersAlert.
        :rtype: bool
        """
        return self._unsubscribed

    @unsubscribed.setter
    def unsubscribed(self, unsubscribed: bool):
        """Sets the unsubscribed of this UsersAlert.

        Whether the alert has been unsubscribed from. Different from if the alert does not exist yet.  # noqa: E501

        :param unsubscribed: The unsubscribed of this UsersAlert.
        :type unsubscribed: bool
        """

        self._unsubscribed = unsubscribed



BASE_REQUIRED_FEATURES = [
    "address",
    "bedroomsTotal",
    "bathroomsFull",
    "bathroomsTotal",
    "buildingType",
    "enclosedParking",
    "directionFaces",
    "latitude",
    "longitude",
    "parking",
    "style",
    "totalParking",
]

CONDO_ONLY_REQUIRED_FEATURES = [
    "associationFee",
    "bedroomsStandard",
    "buildingPlaceId",
]

CONDO_APARTMENT_ONLY_REQUIRED_FEATURES = [
    "unitNumber",
]

RESIDENTIAL_ONLY_REQUIRED_FEATURES = [
    "basement",
    "exterior",
    "heatingType",
]

LOW_RISE_NON_CONDO_STYLES = {
    "2 1/2 Storey",
    "1 1/2 Storey",
    "Bungalow",
    "3-Storey",
    "Multi-Level",
    "2-Storey",
    "Stacked Townhse",
}

# TRREB municipalities map - https://www.torontomls.net/Communities/map.html
# properlyMunicipalityCode format - https://github.com/GoProperly/airflow-pipelines/blob/b5a959e64ccbb796f65970477b8772a5e502444d/dags/rets_creb_idx.py#L281
SUPPORTED_MUNICIPALITY_CODES = {
    # Durham - Ajax, Brock, Clarington, Oshawa, Pickering, Scugog, Uxbridge, Whitby
    "ajax-on-ca",
    "brock-on-ca",
    "clarington-on-ca",
    "oshawa-on-ca",
    "pickering-on-ca",
    "scugog-on-ca",
    "uxbridge-on-ca",
    "whitby-on-ca",
    # Halton - Burlington, Halton Hills, Milton, Oakville
    "burlington-on-ca",
    "halton_hills-on-ca",
    "milton-on-ca",
    "oakville-on-ca",
    # Peel - Brampton, Caledon, Mississauga
    "brampton-on-ca",
    "caledon-on-ca",
    "mississauga-on-ca",
    # Toronto
    "toronto-on-ca",
    # York - Aurora, East Gwillimbury, Geogina, King, Markham, Newmarket, Richmond Hill, Whitchurch-Stouville, Vaughan
    "aurora-on-ca",
    "east_gwillimbury-on-ca",
    "georgina-on-ca",
    "king-on-ca",
    "markham-on-ca",
    "newmarket-on-ca",
    "richmond_hill-on-ca",
    "whitchurch_stouffville-on-ca",
    "vaughan-on-ca",
}


def _is_apartment(model_property: dict) -> bool:
    building_type = model_property.get("buildingType") or ""
    style = model_property.get("style") or ""
    if building_type == "High Rise Apartment":
        return True
    if building_type == "Lowrise Apartment":
        return style not in LOW_RISE_NON_CONDO_STYLES


def check_property_price_avm_ready(model_property: dict) -> bool:
    """
    Determines whether there is enough data to get a reasonable AVM price estimate
    :param model_property: dictionary of property values in ModelProperty spec
    :return: True if the input contains enough data for a reasonable AVM price estimate
    """
    city_code = model_property.get("properlyCityCode")
    municipality_code = model_property.get("properlyMunicipalityCode")

    # Initially we only support the GTA
    if (
        city_code != "toronto-on-ca"
        or municipality_code not in SUPPORTED_MUNICIPALITY_CODES
    ):
        return False

    if "associationFee" in model_property and _is_apartment(model_property):
        # condo apartments require unit numbers
        required_features = (
            BASE_REQUIRED_FEATURES
            + CONDO_ONLY_REQUIRED_FEATURES
            + CONDO_APARTMENT_ONLY_REQUIRED_FEATURES
        )
    elif "associationFee" in model_property:
        # condo, non-apartments does NOT require unit numbers
        # Because we map some non apartment styles to lowrise apartment,
        # we should allow records without unit numbers as long as they are really not apartment units.
        # Lowrise apartment style mapping: https://github.com/GoProperly/airflow-pipelines/blob/master/dags/toronto/rets/tasks.py#L524-L528
        required_features = BASE_REQUIRED_FEATURES + CONDO_ONLY_REQUIRED_FEATURES
    else:
        required_features = BASE_REQUIRED_FEATURES + RESIDENTIAL_ONLY_REQUIRED_FEATURES

    for feature in required_features:
        if feature not in model_property:
            return False

    return True



# coding: utf-8

# flake8: noqa
from __future__ import absolute_import
# import models into model package
from properly_model_python.favourite_models.models.listing_favourites import ListingFavourites
from properly_model_python.favourite_models.models.listing_favourites_audit_log import ListingFavouritesAuditLog
from properly_model_python.favourite_models.models.user_favourites import UserFavourites



# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from properly_model_python.models.base_model_ import Model
from properly_model_python import util


class LatLng(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, lat: float=None, lng: float=None):  # noqa: E501
        """LatLng - a model defined in Swagger

        :param lat: The lat of this LatLng.  # noqa: E501
        :type lat: float
        :param lng: The lng of this LatLng.  # noqa: E501
        :type lng: float
        """
        self.swagger_types = {
            'lat': float,
            'lng': float
        }

        self.attribute_map = {
            'lat': 'lat',
            'lng': 'lng'
        }

        self._lat = lat
        self._lng = lng

    @classmethod
    def from_dict(cls, dikt) -> 'LatLng':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The LatLng of this LatLng.  # noqa: E501
        :rtype: LatLng
        """
        return util.deserialize_model(dikt, cls)

    @property
    def lat(self) -> float:
        """Gets the lat of this LatLng.


        :return: The lat of this LatLng.
        :rtype: float
        """
        return self._lat

    @lat.setter
    def lat(self, lat: float):
        """Sets the lat of this LatLng.


        :param lat: The lat of this LatLng.
        :type lat: float
        """

        self._lat = lat

    @property
    def lng(self) -> float:
        """Gets the lng of this LatLng.


        :return: The lng of this LatLng.
        :rtype: float
        """
        return self._lng

    @lng.setter
    def lng(self, lng: float):
        """Sets the lng of this LatLng.


        :param lng: The lng of this LatLng.
        :type lng: float
        """

        self._lng = lng
